/*
 * Copyright (c) 2006-2010 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef __gpx_h
#define __gpx_h

#include <stdio.h>
#include <time.h>

typedef struct gps_fix_t {

  double time;  /* Time of update, seconds since Unix epoch */
  double ept;           /* Expected time uncertainty */
  double latitude;      /* Latitude in degrees (valid if mode >= 2) */
  double epy;   /* Latitude position uncertainty, meters */
  double longitude;     /* Longitude in degrees (valid if mode >= 2) */
  double epx;   /* Longitude position uncertainty, meters */
  double altitude;      /* Altitude in meters (valid if mode == 3) */
  double epv;   /* Vertical position uncertainty, meters */

  double track; /* Course made good (relative to true north) */
  double epd;           /* Track uncertainty, degrees */
  double speed; /* Speed over ground, meters/sec */
  double eps;           /* Speed uncertainty, meters/sec */
  double climb;       /* Vertical speed, meters/sec */
  double epc;           /* Vertical speed uncertainty */
} gps_fix_t;

void print_gpx_header(FILE *);
void print_gpx_trk_start (FILE*);
void print_gpx_trk_end (FILE*);
void print_gpx_footer (FILE*);
void print_fix(struct gps_fix_t *, struct tm *, FILE*);
void conditionally_log_fix(struct gps_fix_t *, FILE*);


#endif
